"use client"

import type React from "react"

import { useState } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Checkbox } from "@/components/ui/checkbox"
import { FileText, Upload, ArrowLeft, Calculator } from "lucide-react"
import Link from "next/link"
import { getAuthenticatedUser } from "@/lib/auth"
import { useDataActions } from "@/hooks/use-data-store"

export default function PlaceOrderPage() {
  const router = useRouter()
  const { addOrder } = useDataActions()
  const [formData, setFormData] = useState({
    title: "",
    description: "",
    subject: "",
    academicLevel: "",
    pages: 1,
    deadline: "",
    attachments: null as File[] | null,
    preferredWriter: "",
    urgentOrder: false,
  })
  const [isLoading, setIsLoading] = useState(false)
  const [estimatedPrice, setEstimatedPrice] = useState(0)

  // Calculate price based on pages, academic level, and deadline
  const calculatePrice = () => {
    const basePrice = 10 // Updated base price per page

    // Academic level multiplier
    const levelMultipliers = {
      "high-school": 1.0,
      undergraduate: 1.3,
      masters: 1.6,
      phd: 2.2,
    }

    // Urgency multiplier based on deadline
    const deadline = new Date(formData.deadline)
    const now = new Date()
    const daysUntilDeadline = Math.ceil((deadline.getTime() - now.getTime()) / (1000 * 60 * 60 * 24))

    let urgencyMultiplier = 1.0
    if (daysUntilDeadline <= 1) urgencyMultiplier = 2.5
    else if (daysUntilDeadline <= 3) urgencyMultiplier = 1.8
    else if (daysUntilDeadline <= 7) urgencyMultiplier = 1.4
    else if (daysUntilDeadline <= 14) urgencyMultiplier = 1.2

    const levelMult = levelMultipliers[formData.academicLevel as keyof typeof levelMultipliers] || 1.0
    const price = formData.pages * basePrice * levelMult * urgencyMultiplier

    setEstimatedPrice(Math.round(price))
  }

  // Recalculate price when relevant fields change
  useState(() => {
    if (formData.pages && formData.academicLevel && formData.deadline) {
      calculatePrice()
    }
  })

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setIsLoading(true)

    try {
      const user = getAuthenticatedUser()
      if (!user) {
        router.push("/auth/login")
        return
      }

      // Create new order
      const newOrder = {
        id: `ORD-${Date.now()}`,
        title: formData.title,
        description: formData.description,
        client: user.email,
        clientName: user.name || user.email.split("@")[0],
        clientRating: 4.5, // Default rating
        status: "payment_pending" as const,
        academicLevel: formData.academicLevel,
        subject: formData.subject,
        pages: formData.pages,
        deadline: formData.deadline,
        amount: estimatedPrice,
        budget: estimatedPrice,
        created: new Date().toISOString(),
        priority: formData.urgentOrder ? ("high" as const) : ("normal" as const),
        progress: 0,
        requirements: formData.description,
        attachments: formData.attachments ? formData.attachments.map((f) => f.name) : [],
        bidsCount: 0,
        urgency: formData.urgentOrder ? ("high" as const) : ("normal" as const),
        postedDate: new Date().toISOString(),
        lastUpdate: new Date().toISOString(),
        messages: 0,
        writerApplications: [],
      }

      // Add order to store
      addOrder(newOrder)

      // Simulate order creation delay
      await new Promise((resolve) => setTimeout(resolve, 2000))

      // Show PayPal payment prompt message
      alert(`Order submitted successfully! 

A PayPal payment request for $${estimatedPrice} has been sent to your email address. 

Please check your email and complete the payment to proceed with your order.

Order ID: ${newOrder.id}

Your order will be visible to qualified writers once payment is confirmed. You'll receive notifications about writer applications and can communicate directly through our messaging system.`)

      // Redirect to dashboard with pending payment status
      router.push("/client/dashboard?orderSubmitted=true&paymentPending=true")
    } catch (error) {
      alert("Error submitting order. Please try again.")
    } finally {
      setIsLoading(false)
    }
  }

  const handleFileUpload = (e: React.ChangeEvent<HTMLInputElement>) => {
    if (e.target.files) {
      setFormData({ ...formData, attachments: Array.from(e.target.files) })
    }
  }

  return (
    <div className="min-h-screen bg-gray-50">
      {/* Header */}
      <header className="bg-white shadow-sm border-b">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-4">
            <div className="flex items-center">
              <FileText className="h-8 w-8 text-blue-600" />
              <span className="ml-2 text-xl font-bold text-gray-900">ProEssayWorks</span>
            </div>
            <Link href="/client/dashboard">
              <Button variant="outline">
                <ArrowLeft className="h-4 w-4 mr-2" />
                Back to Dashboard
              </Button>
            </Link>
          </div>
        </div>
      </header>

      <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="mb-8">
          <h1 className="text-3xl font-bold text-gray-900 mb-2">Place New Order</h1>
          <p className="text-gray-600">Fill out the details for your academic writing project</p>
        </div>

        <div className="grid grid-cols-1 lg:grid-cols-3 gap-8">
          <div className="lg:col-span-2">
            <Card>
              <CardHeader>
                <CardTitle>Order Details</CardTitle>
                <CardDescription>Provide comprehensive information about your project</CardDescription>
              </CardHeader>
              <CardContent>
                <form onSubmit={handleSubmit} className="space-y-6">
                  <div className="space-y-2">
                    <Label htmlFor="title">Project Title *</Label>
                    <Input
                      id="title"
                      placeholder="Enter a descriptive title for your project"
                      value={formData.title}
                      onChange={(e) => setFormData({ ...formData, title: e.target.value })}
                      required
                    />
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor="description">Project Description *</Label>
                    <Textarea
                      id="description"
                      placeholder="Provide detailed instructions, requirements, and any specific guidelines..."
                      rows={6}
                      value={formData.description}
                      onChange={(e) => setFormData({ ...formData, description: e.target.value })}
                      required
                    />
                  </div>

                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div className="space-y-2">
                      <Label htmlFor="subject">Subject/Topic *</Label>
                      <Select
                        value={formData.subject}
                        onValueChange={(value) => setFormData({ ...formData, subject: value })}
                      >
                        <SelectTrigger>
                          <SelectValue placeholder="Select subject" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectItem value="psychology">Psychology</SelectItem>
                          <SelectItem value="business">Business</SelectItem>
                          <SelectItem value="literature">Literature</SelectItem>
                          <SelectItem value="history">History</SelectItem>
                          <SelectItem value="sociology">Sociology</SelectItem>
                          <SelectItem value="nursing">Nursing</SelectItem>
                          <SelectItem value="education">Education</SelectItem>
                          <SelectItem value="law">Law</SelectItem>
                          <SelectItem value="economics">Economics</SelectItem>
                          <SelectItem value="environmental-science">Environmental Science</SelectItem>
                          <SelectItem value="computer-science">Computer Science</SelectItem>
                          <SelectItem value="marketing">Marketing</SelectItem>
                          <SelectItem value="other">Other</SelectItem>
                        </SelectContent>
                      </Select>
                    </div>

                    <div className="space-y-2">
                      <Label htmlFor="academicLevel">Academic Level *</Label>
                      <Select
                        value={formData.academicLevel}
                        onValueChange={(value) => setFormData({ ...formData, academicLevel: value })}
                      >
                        <SelectTrigger>
                          <SelectValue placeholder="Select level" />
                        </SelectTrigger>
                        <SelectContent>
                          <SelectItem value="high-school">High School</SelectItem>
                          <SelectItem value="undergraduate">Undergraduate</SelectItem>
                          <SelectItem value="masters">Master's</SelectItem>
                          <SelectItem value="phd">PhD</SelectItem>
                        </SelectContent>
                      </Select>
                    </div>
                  </div>

                  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                    <div className="space-y-2">
                      <Label htmlFor="pages">Number of Pages *</Label>
                      <Input
                        id="pages"
                        type="number"
                        min="1"
                        max="100"
                        value={formData.pages}
                        onChange={(e) => setFormData({ ...formData, pages: Number.parseInt(e.target.value) || 1 })}
                        required
                      />
                      <p className="text-xs text-gray-500">1 page = 275 words</p>
                    </div>

                    <div className="space-y-2">
                      <Label htmlFor="deadline">Deadline *</Label>
                      <Input
                        id="deadline"
                        type="datetime-local"
                        value={formData.deadline}
                        onChange={(e) => setFormData({ ...formData, deadline: e.target.value })}
                        required
                      />
                    </div>
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor="attachments">Attachments (Optional)</Label>
                    <div className="border-2 border-dashed border-gray-300 rounded-lg p-6 text-center">
                      <Upload className="h-8 w-8 text-gray-400 mx-auto mb-2" />
                      <p className="text-sm text-gray-600 mb-2">
                        Upload supporting files, rubrics, or reference materials
                      </p>
                      <Input id="attachments" type="file" multiple onChange={handleFileUpload} className="hidden" />
                      <Button
                        type="button"
                        variant="outline"
                        onClick={() => document.getElementById("attachments")?.click()}
                      >
                        Choose Files
                      </Button>
                      {formData.attachments && (
                        <div className="mt-2 text-sm text-gray-600">{formData.attachments.length} file(s) selected</div>
                      )}
                    </div>
                  </div>

                  <div className="space-y-2">
                    <Label htmlFor="preferredWriter">Preferred Writer (Optional)</Label>
                    <Select
                      value={formData.preferredWriter}
                      onValueChange={(value) => setFormData({ ...formData, preferredWriter: value })}
                    >
                      <SelectTrigger>
                        <SelectValue placeholder="Select a writer you've worked with before" />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="dr-sarah-johnson">Dr. Sarah Johnson</SelectItem>
                        <SelectItem value="prof-michael-chen">Prof. Michael Chen</SelectItem>
                        <SelectItem value="dr-emily-davis">Dr. Emily Davis</SelectItem>
                      </SelectContent>
                    </Select>
                  </div>

                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="urgent"
                      checked={formData.urgentOrder}
                      onCheckedChange={(checked) => setFormData({ ...formData, urgentOrder: checked as boolean })}
                    />
                    <Label htmlFor="urgent" className="text-sm">
                      This is an urgent order (additional charges may apply)
                    </Label>
                  </div>

                  <Button type="submit" className="w-full" disabled={isLoading}>
                    {isLoading ? "Placing Order..." : "Place Order"}
                  </Button>
                </form>
              </CardContent>
            </Card>
          </div>

          <div>
            <Card className="sticky top-4">
              <CardHeader>
                <CardTitle className="flex items-center">
                  <Calculator className="h-5 w-5 mr-2" />
                  Order Summary
                </CardTitle>
              </CardHeader>
              <CardContent className="space-y-4">
                <div className="space-y-2">
                  <div className="flex justify-between text-sm">
                    <span>Pages:</span>
                    <span>{formData.pages}</span>
                  </div>
                  <div className="flex justify-between text-sm">
                    <span>Academic Level:</span>
                    <span className="capitalize">{formData.academicLevel?.replace("-", " ")}</span>
                  </div>
                  <div className="flex justify-between text-sm">
                    <span>Subject:</span>
                    <span className="capitalize">{formData.subject}</span>
                  </div>
                  {formData.deadline && (
                    <div className="flex justify-between text-sm">
                      <span>Deadline:</span>
                      <span>{new Date(formData.deadline).toLocaleDateString()}</span>
                    </div>
                  )}
                </div>

                <div className="border-t pt-4">
                  <div className="flex justify-between font-semibold">
                    <span>Estimated Total:</span>
                    <span className="text-lg text-blue-600">${estimatedPrice}</span>
                  </div>
                  <p className="text-xs text-gray-500 mt-1">Final price may vary based on writer selection</p>
                </div>

                <div className="bg-blue-50 p-3 rounded-lg">
                  <h4 className="font-semibold text-sm mb-2">What happens next?</h4>
                  <ol className="text-xs space-y-1 text-gray-600">
                    <li>1. Submit your order details</li>
                    <li>2. Receive PayPal payment request via email</li>
                    <li>3. Complete payment through PayPal</li>
                    <li>4. Qualified writers apply for your order</li>
                    <li>5. Admin assigns the best writer</li>
                    <li>6. Track progress and communicate</li>
                    <li>7. Receive completed work</li>
                  </ol>
                </div>
              </CardContent>
            </Card>
          </div>
        </div>
      </div>
    </div>
  )
}
